Class: Macros4Cuke::Templating::StaticText

Inherits:
Object
  • Object
show all
Defined in:
lib/macros4cuke/templating/engine.rb

Overview

Class used internally by the template engine.
Represents a static piece of text from a template.
A static text is a text that is reproduced verbatim when rendering a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(aSourceText) ⇒ StaticText



26
27
28
# File 'lib/macros4cuke/templating/engine.rb', line 26

def initialize(aSourceText)
  @source = aSourceText
end

Instance Attribute Details

#sourceObject (readonly)

The static text extracted from the original template.



21
22
23
# File 'lib/macros4cuke/templating/engine.rb', line 21

def source
  @source
end

Instance Method Details

#render(aContextObject, theLocals) ⇒ String

Render the static text. This method has the same signature as the Engine#render method.



35
36
37
# File 'lib/macros4cuke/templating/engine.rb', line 35

def render(aContextObject, theLocals)
  return source
end